==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/X12AgreementContentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.X12AgreementContentArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The X12 agreement content.
 * @property receiveAgreement The X12 one-way receive agreement.
 * @property sendAgreement The X12 one-way send agreement.
 */
public data class X12AgreementContentArgs(
    public val receiveAgreement: Output<X12OneWayAgreementArgs>,
    public val sendAgreement: Output<X12OneWayAgreementArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.X12AgreementContentArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.X12AgreementContentArgs =
        com.pulumi.azurenative.logic.inputs.X12AgreementContentArgs.builder()
            .receiveAgreement(receiveAgreement.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .sendAgreement(sendAgreement.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [X12AgreementContentArgs].
 */
@PulumiTagMarker
public class X12AgreementContentArgsBuilder internal constructor() {
    private var receiveAgreement: Output<X12OneWayAgreementArgs>? = null

    private var sendAgreement: Output<X12OneWayAgreementArgs>? = null

    /**
     * @param value The X12 one-way receive agreement.
     */
    @JvmName("prgxxwialdewjpcj")
    public suspend fun receiveAgreement(`value`: Output<X12OneWayAgreementArgs>) {
        this.receiveAgreement = value
    }

    /**
     * @param value The X12 one-way send agreement.
     */
    @JvmName("mmuamnskkgvcteww")
    public suspend fun sendAgreement(`value`: Output<X12OneWayAgreementArgs>) {
        this.sendAgreement = value
    }

    /**
     * @param value The X12 one-way receive agreement.
     */
    @JvmName("xjgktwqcwxppvpoy")
    public suspend fun receiveAgreement(`value`: X12OneWayAgreementArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.receiveAgreement = mapped
    }

    /**
     * @param argument The X12 one-way receive agreement.
     */
    @JvmName("hqlkfxbvilxtwnuf")
    public suspend fun receiveAgreement(argument: suspend X12OneWayAgreementArgsBuilder.() -> Unit) {
        val toBeMapped = X12OneWayAgreementArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.receiveAgreement = mapped
    }

    /**
     * @param value The X12 one-way send agreement.
     */
    @JvmName("yikihnbpiumdunev")
    public suspend fun sendAgreement(`value`: X12OneWayAgreementArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sendAgreement = mapped
    }

    /**
     * @param argument The X12 one-way send agreement.
     */
    @JvmName("yeldidqabaufdcbx")
    public suspend fun sendAgreement(argument: suspend X12OneWayAgreementArgsBuilder.() -> Unit) {
        val toBeMapped = X12OneWayAgreementArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sendAgreement = mapped
    }

    internal fun build(): X12AgreementContentArgs = X12AgreementContentArgs(
        receiveAgreement = receiveAgreement ?: throw PulumiNullFieldException("receiveAgreement"),
        sendAgreement = sendAgreement ?: throw PulumiNullFieldException("sendAgreement"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/X12AgreementContentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.X12AgreementContentArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The X12 agreement content.
 * @property receiveAgreement The X12 one-way receive agreement.
 * @property sendAgreement The X12 one-way send agreement.
 */
public data class X12AgreementContentArgs(
    public val receiveAgreement: Output<X12OneWayAgreementArgs>,
    public val sendAgreement: Output<X12OneWayAgreementArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.X12AgreementContentArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.X12AgreementContentArgs =
        com.pulumi.azurenative.logic.inputs.X12AgreementContentArgs.builder()
            .receiveAgreement(receiveAgreement.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .sendAgreement(sendAgreement.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [X12AgreementContentArgs].
 */
@PulumiTagMarker
public class X12AgreementContentArgsBuilder internal constructor() {
    private var receiveAgreement: Output<X12OneWayAgreementArgs>? = null

    private var sendAgreement: Output<X12OneWayAgreementArgs>? = null

    /**
     * @param value The X12 one-way receive agreement.
     */
    @JvmName("uemyicsbeotnooab")
    public suspend fun receiveAgreement(`value`: Output<X12OneWayAgreementArgs>) {
        this.receiveAgreement = value
    }

    /**
     * @param value The X12 one-way send agreement.
     */
    @JvmName("uvjbbdnytayxcdfo")
    public suspend fun sendAgreement(`value`: Output<X12OneWayAgreementArgs>) {
        this.sendAgreement = value
    }

    /**
     * @param value The X12 one-way receive agreement.
     */
    @JvmName("ytabswfjdnluyuqx")
    public suspend fun receiveAgreement(`value`: X12OneWayAgreementArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.receiveAgreement = mapped
    }

    /**
     * @param argument The X12 one-way receive agreement.
     */
    @JvmName("vvxtvmdvqmohemig")
    public suspend fun receiveAgreement(argument: suspend X12OneWayAgreementArgsBuilder.() -> Unit) {
        val toBeMapped = X12OneWayAgreementArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.receiveAgreement = mapped
    }

    /**
     * @param value The X12 one-way send agreement.
     */
    @JvmName("qignondhtwbaleic")
    public suspend fun sendAgreement(`value`: X12OneWayAgreementArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sendAgreement = mapped
    }

    /**
     * @param argument The X12 one-way send agreement.
     */
    @JvmName("ojohqjsoeajgqdly")
    public suspend fun sendAgreement(argument: suspend X12OneWayAgreementArgsBuilder.() -> Unit) {
        val toBeMapped = X12OneWayAgreementArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sendAgreement = mapped
    }

    internal fun build(): X12AgreementContentArgs = X12AgreementContentArgs(
        receiveAgreement = receiveAgreement ?: throw PulumiNullFieldException("receiveAgreement"),
        sendAgreement = sendAgreement ?: throw PulumiNullFieldException("sendAgreement"),
    )
}
